<?php

	/**
	 * Russian KOI8 language file for phpPgAdmin. 
	 * @maintainer Alexander Khodorivsky [askh@ukr.net]
	 *
	 * $Id: russian.php,v 1.12 2007/04/24 11:42:07 soranzo Exp $
	 */

	// Language and character set
	$lang['applang'] = '&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081; &#1050;&#1054;&#1048;8';
	$lang['appcharset'] = 'KOI8-R';
	$lang['applocale'] = 'ru_RU';
  	$lang['appdbencoding'] = 'KOI8';
	$lang['applangdir'] = 'ltr';

	// Welcome  
	$lang['strintro'] = '&#1044;&#1086;&#1073;&#1088;&#1086; &#1087;&#1086;&#1078;&#1072;&#1083;&#1086;&#1074;&#1072;&#1090;&#1100; &#1074; phpPgAdmin.';
	$lang['strppahome'] = 'phpPgAdmin - &#1076;&#1086;&#1084;&#1072;&#1096;&#1085;&#1103;&#1103; &#1089;&#1090;&#1088;&#1072;&#1085;&#1080;&#1094;&#1072;';
	$lang['strpgsqlhome'] = 'PostgreSQL - &#1076;&#1086;&#1084;&#1072;&#1096;&#1085;&#1103;&#1103; &#1089;&#1090;&#1088;&#1072;&#1085;&#1080;&#1094;&#1072;';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL - &#1076;&#1086;&#1082;&#1091;&#1084;&#1077;&#1085;&#1090;&#1072;&#1094;&#1080;&#1103; (&#1083;&#1086;&#1082;&#1072;&#1083;&#1100;&#1085;&#1086;)';
	$lang['strreportbug'] = '&#1054;&#1090;&#1095;&#1077;&#1090; &#1086;&#1073; &#1086;&#1096;&#1080;&#1073;&#1082;&#1072;&#1093;';
	$lang['strviewfaq'] = '&#1055;&#1088;&#1086;&#1089;&#1084;&#1086;&#1090;&#1088; &#1086;&#1085;&#1083;&#1072;&#1081;&#1085; FAQ';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	
	// Basic strings
	$lang['strlogin'] = '&#1051;&#1086;&#1075;&#1080;&#1085;';
	$lang['strloginfailed'] = '&#1053;&#1077;&#1074;&#1077;&#1088;&#1085;&#1099;&#1081; &#1083;&#1086;&#1075;&#1080;&#1085;';
	$lang['strlogindisallowed'] = '&#1051;&#1086;&#1075;&#1080;&#1085; &#1085;&#1077;&#1076;&#1086;&#1087;&#1091;&#1089;&#1090;&#1080;&#1084; &#1087;&#1086; &#1089;&#1086;&#1086;&#1073;&#1088;&#1072;&#1078;&#1077;&#1085;&#1080;&#1103;&#1084; &#1073;&#1077;&#1079;&#1086;&#1087;&#1072;&#1089;&#1085;&#1086;&#1089;&#1090;&#1080;';
	$lang['strserver'] = '&#1057;&#1077;&#1088;&#1074;&#1077;&#1088;';
	$lang['strlogout'] = '&#1055;&#1077;&#1088;&#1077;&#1088;&#1077;&#1075;&#1080;&#1089;&#1090;&#1088;&#1072;&#1094;&#1080;&#1103;';
	$lang['strowner'] = '&#1055;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;';
	$lang['straction'] = '&#1044;&#1077;&#1081;&#1089;&#1090;&#1074;&#1080;&#1077;';
	$lang['stractions'] = '&#1044;&#1077;&#1081;&#1089;&#1090;&#1074;&#1080;&#1103;';
	$lang['strname'] = '&#1048;&#1084;&#1103;';
	$lang['strdefinition'] = '&#1054;&#1087;&#1088;&#1077;&#1076;&#1077;&#1083;&#1077;&#1085;&#1080;&#1077;';
	$lang['strproperties'] = '&#1057;&#1074;&#1086;&#1081;&#1089;&#1090;&#1074;&#1072;';
	$lang['strbrowse'] = '&#1055;&#1088;&#1086;&#1089;&#1084;&#1086;&#1090;&#1088;&#1077;&#1090;&#1100;';
	$lang['strdrop'] = '&#1059;&#1076;&#1072;&#1083;&#1080;&#1090;&#1100;';
	$lang['strdropped'] = '&#1059;&#1076;&#1072;&#1083;&#1077;&#1085;&#1086;';
	$lang['strnull'] = 'Null';
	$lang['strnotnull'] = 'Not Null';
	$lang['strprev'] = '&lt; &#1055;&#1088;&#1077;&#1076;&#1099;&#1076;.';
	$lang['strnext'] = '&#1057;&#1083;&#1077;&#1076;. &gt;';
	$lang['strfirst'] = '&lt;&lt; &#1055;&#1077;&#1088;&#1074;.';
	$lang['strlast'] = '&#1055;&#1086;&#1089;&#1083;. &gt;&gt;';
	$lang['strfailed'] = '&#1055;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;';
	$lang['strcreate'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100;';
	$lang['strcreated'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1086;';
	$lang['strcomment'] = '&#1050;&#1086;&#1084;&#1084;&#1077;&#1085;&#1090;&#1072;&#1088;&#1080;&#1081;';
	$lang['strlength'] = '&#1044;&#1083;&#1080;&#1085;&#1072;';
	$lang['strdefault'] = '&#1055;&#1086; &#1091;&#1084;&#1086;&#1083;&#1095;&#1072;&#1085;&#1080;&#1102;';
	$lang['stralter'] = '&#1048;&#1079;&#1084;&#1077;&#1085;&#1080;&#1090;&#1100;';
	$lang['strok'] = 'OK';
	$lang['strcancel'] = '&#1054;&#1090;&#1084;&#1077;&#1085;&#1080;&#1090;&#1100;';
	$lang['strsave'] = '&#1057;&#1086;&#1093;&#1088;&#1072;&#1085;&#1080;&#1090;&#1100;';
	$lang['strreset'] = '&#1057;&#1073;&#1088;&#1086;&#1089;&#1080;&#1090;&#1100;';
	$lang['strinsert'] = '&#1042;&#1089;&#1090;&#1072;&#1074;&#1080;&#1090;&#1100;';
	$lang['strselect'] = '&#1042;&#1099;&#1073;&#1088;&#1072;&#1090;&#1100;';
	$lang['strdelete'] = '&#1059;&#1076;&#1072;&#1083;&#1080;&#1090;&#1100;';
	$lang['strupdate'] = '&#1054;&#1073;&#1085;&#1086;&#1074;&#1080;&#1090;&#1100;';
	$lang['strreferences'] = '&#1057;&#1089;&#1099;&#1083;&#1082;&#1080;';
	$lang['stryes'] = '&#1044;&#1072;';
	$lang['strno'] = '&#1053;&#1077;&#1090;';
	$lang['strtrue'] = '&#1048;&#1089;&#1090;&#1080;&#1085;&#1072;';
	$lang['strfalse'] = '&#1051;&#1086;&#1078;&#1100;';
	$lang['stredit'] = '&#1056;&#1077;&#1076;&#1072;&#1082;&#1090;&#1080;&#1088;&#1086;&#1074;&#1072;&#1090;&#1100;';
	$lang['strcolumns'] = '&#1040;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;&#1099;';
	$lang['strrows'] = '&#1079;&#1072;&#1087;&#1080;&#1089;(&#1100;/&#1080;/&#1077;&#1081;)';
	$lang['strrowsaff'] = '&#1079;&#1072;&#1087;&#1080;&#1089;(&#1100;/&#1080;/&#1077;&#1081;) &#1086;&#1073;&#1088;&#1072;&#1073;&#1086;&#1090;&#1072;&#1085;&#1086;.';
	$lang['strobjects'] = '&#1086;&#1073;&#1098;&#1077;&#1082;&#1090;(&#1072;/&#1086;&#1074;)';
	$lang['strexample'] = '&#1080; &#1090;.&#1076;.';
	$lang['strback'] = '&#1053;&#1072;&#1079;&#1072;&#1076;'; 	
	$lang['strqueryresults'] = '&#1056;&#1077;&#1079;&#1091;&#1083;&#1100;&#1090;&#1072;&#1090;&#1099; &#1079;&#1072;&#1087;&#1088;&#1086;&#1089;&#1072;';
	$lang['strshow'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100;';
	$lang['strempty'] = '&#1054;&#1095;&#1080;&#1089;&#1090;&#1080;&#1090;&#1100;';
	$lang['strlanguage'] = '&#1071;&#1079;&#1099;&#1082;';
	$lang['strencoding'] = '&#1050;&#1086;&#1076;&#1080;&#1088;&#1086;&#1074;&#1082;&#1072;';
	$lang['strvalue'] = '&#1042;&#1077;&#1083;&#1080;&#1095;&#1080;&#1085;&#1072;';
	$lang['strunique'] = '&#1059;&#1085;&#1080;&#1082;&#1072;&#1083;&#1100;&#1085;&#1099;&#1081;';
	$lang['strprimary'] = '&#1055;&#1077;&#1088;&#1074;&#1080;&#1095;&#1085;&#1099;&#1081;';
	$lang['strexport'] = '&#1069;&#1082;&#1089;&#1087;&#1086;&#1088;&#1090;';
	$lang['strimport'] = '&#1048;&#1084;&#1087;&#1086;&#1088;&#1090;';
	$lang['strsql'] = 'SQL';
	$lang['strgo'] = '&#1042;&#1099;&#1087;&#1086;&#1083;&#1085;&#1080;&#1090;&#1100;';
	$lang['stradmin'] = '&#1059;&#1087;&#1088;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077;';
	$lang['strvacuum'] = '&#1055;&#1077;&#1088;&#1077;&#1089;&#1090;&#1088;&#1086;&#1080;&#1090;&#1100;';
	$lang['stranalyze'] = '&#1040;&#1085;&#1072;&#1083;&#1080;&#1079;&#1080;&#1088;&#1086;&#1074;&#1072;&#1090;&#1100;';
	$lang['strclusterindex'] = '&#1050;&#1083;&#1072;&#1089;&#1090;&#1077;&#1088;&#1080;&#1079;&#1086;&#1074;&#1072;&#1090;&#1100;';
	$lang['strclustered'] = '&#1050;&#1083;&#1072;&#1089;&#1090;&#1077;&#1088;&#1080;&#1079;&#1086;&#1074;&#1072;&#1085;?';
	$lang['strreindex'] = '&#1055;&#1077;&#1088;&#1077;&#1089;&#1090;&#1088;&#1086;&#1080;&#1090;&#1100; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;';
	$lang['strrun'] = '&#1042;&#1099;&#1087;&#1086;&#1083;&#1085;&#1080;&#1090;&#1100;';
	$lang['stradd'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1080;&#1090;&#1100;';
	$lang['strevent'] = '&#1057;&#1086;&#1073;&#1099;&#1090;&#1080;&#1077;';
	$lang['strwhere'] = '&#1043;&#1076;&#1077;';
	$lang['strinstead'] = '&#1044;&#1077;&#1083;&#1072;&#1090;&#1100; &#1074;&#1084;&#1077;&#1089;&#1090;&#1086;';
	$lang['strwhen'] = '&#1050;&#1086;&#1075;&#1076;&#1072;';
	$lang['strformat'] = '&#1060;&#1086;&#1088;&#1084;&#1072;&#1090;';
	$lang['strdata'] = '&#1044;&#1072;&#1085;&#1085;&#1099;&#1077;';
	$lang['strconfirm'] = '&#1055;&#1086;&#1076;&#1090;&#1074;&#1077;&#1088;&#1076;&#1080;&#1090;&#1100;';
	$lang['strexpression'] = '&#1042;&#1099;&#1088;&#1072;&#1078;&#1077;&#1085;&#1080;&#1077;';
	$lang['strellipsis'] = '...';
	$lang['strexpand'] = '&#1056;&#1072;&#1089;&#1096;&#1080;&#1088;&#1080;&#1090;&#1100;';
	$lang['strcollapse'] = '&#1057;&#1074;&#1077;&#1088;&#1085;&#1091;&#1090;&#1100;';
	$lang['strexplain'] = '&#1054;&#1073;&#1098;&#1103;&#1089;&#1085;&#1080;&#1090;&#1100;';
	$lang['strexplainanalyze'] = '&#1054;&#1073;&#1098;&#1103;&#1089;&#1085;&#1080;&#1090;&#1100; &#1072;&#1085;&#1072;&#1083;&#1080;&#1079;';
	$lang['strfind'] = '&#1053;&#1072;&#1081;&#1090;&#1080;';
	$lang['stroptions'] = '&#1054;&#1087;&#1094;&#1080;&#1080;';
	$lang['strrefresh'] = '&#1054;&#1073;&#1085;&#1086;&#1074;&#1080;&#1090;&#1100;';
	$lang['strdownload'] = '&#1047;&#1072;&#1075;&#1088;&#1091;&#1079;&#1080;&#1090;&#1100;';
	$lang['strdownloadgzipped'] = '&#1047;&#1072;&#1075;&#1088;&#1091;&#1079;&#1080;&#1090;&#1100; &#1072;&#1088;&#1093;&#1080;&#1074; gzip';
	$lang['strinfo'] = '&#1057;&#1074;&#1077;&#1076;&#1077;&#1085;&#1080;&#1103;';
	$lang['stroids'] = 'OIDs';
	$lang['stradvanced'] = '&#1044;&#1086;&#1087;&#1086;&#1083;&#1085;&#1080;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;';
	$lang['strvariables'] = '&#1055;&#1077;&#1088;&#1077;&#1084;&#1077;&#1085;&#1085;&#1099;&#1077;';
	$lang['strprocess'] = '&#1055;&#1088;&#1086;&#1094;&#1077;&#1089;&#1089;';
	$lang['strprocesses'] = '&#1055;&#1088;&#1086;&#1094;&#1077;&#1089;&#1089;&#1099;';
	$lang['strsetting'] = '&#1054;&#1087;&#1094;&#1080;&#1080;';
	$lang['streditsql'] = '&#1056;&#1077;&#1076;&#1072;&#1082;&#1090;&#1080;&#1088;&#1086;&#1074;&#1072;&#1090;&#1100; SQL';
	$lang['strruntime'] = '&#1042;&#1088;&#1077;&#1084;&#1103; &#1074;&#1099;&#1087;&#1086;&#1083;&#1085;&#1077;&#1085;&#1080;&#1103;: %s &#1084;&#1089;&#1077;&#1082;';
	$lang['strpaginate'] = '&#1053;&#1091;&#1084;&#1077;&#1088;&#1086;&#1074;&#1072;&#1090;&#1100; &#1089;&#1090;&#1088;&#1072;&#1085;&#1080;&#1094;&#1099; &#1089; &#1088;&#1077;&#1079;&#1091;&#1083;&#1100;&#1090;&#1072;&#1090;&#1072;&#1084;&#1080;';
	$lang['struploadscript'] = '&#1080;&#1083;&#1080; &#1079;&#1072;&#1075;&#1088;&#1091;&#1079;&#1080;&#1090;&#1100; SQL-&#1089;&#1082;&#1088;&#1080;&#1087;&#1090;:';
	$lang['strstarttime'] = '&#1042;&#1088;&#1077;&#1084;&#1103; &#1085;&#1072;&#1095;&#1072;&#1083;&#1072;';
	$lang['strfile'] = '&#1060;&#1072;&#1081;&#1083;';
	$lang['strfileimported'] = '&#1060;&#1072;&#1081;&#1083; &#1080;&#1084;&#1087;&#1086;&#1088;&#1090;&#1080;&#1088;&#1086;&#1074;&#1072;&#1085;.';

	// Error handling
	$lang['strbadconfig'] = '&#1042;&#1072;&#1096; config.inc.php &#1103;&#1074;&#1083;&#1103;&#1077;&#1090;&#1089;&#1103; &#1091;&#1089;&#1090;&#1072;&#1088;&#1077;&#1074;&#1096;&#1080;&#1084;. &#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1086;&#1073;&#1085;&#1086;&#1074;&#1080;&#1090;&#1100; &#1077;&#1075;&#1086; &#1080;&#1079; config.inc.php-dist.';
	$lang['strnotloaded'] = '&#1042;&#1072;&#1096;&#1072; &#1080;&#1085;&#1089;&#1090;&#1072;&#1083;&#1103;&#1094;&#1080;&#1103; PHP &#1085;&#1077; &#1087;&#1086;&#1076;&#1076;&#1077;&#1088;&#1078;&#1080;&#1074;&#1072;&#1077;&#1090; PostgreSQL. &#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1087;&#1077;&#1088;&#1077;&#1089;&#1086;&#1073;&#1088;&#1072;&#1090;&#1100; PHP, &#1080;&#1089;&#1087;&#1086;&#1083;&#1100;&#1079;&#1091;&#1103; &#1087;&#1072;&#1088;&#1072;&#1084;&#1077;&#1090;&#1088; --with-pgsql &#1076;&#1083;&#1103; configure.';
	$lang['strbadschema'] = '&#1054;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;&#1072; &#1085;&#1077;&#1074;&#1077;&#1088;&#1085;&#1072;&#1103; &#1089;&#1093;&#1077;&#1084;&#1072;.';
	$lang['strbadencoding'] = 'Failed to set client encoding in database.';
	$lang['strsqlerror'] = '&#1054;&#1096;&#1080;&#1073;&#1082;&#1072; SQL:';
	$lang['strinstatement'] = '&#1042; &#1086;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1077;:';
	$lang['strinvalidparam'] = '&#1053;&#1077;&#1074;&#1077;&#1088;&#1085;&#1099;&#1081; &#1087;&#1072;&#1088;&#1072;&#1084;&#1077;&#1090;&#1088; &#1089;&#1082;&#1088;&#1080;&#1087;&#1090;&#1072;.';
	$lang['strnodata'] = '&#1044;&#1072;&#1085;&#1085;&#1099;&#1093; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strnoobjects'] = '&#1054;&#1073;&#1098;&#1077;&#1082;&#1090;&#1086;&#1074; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strrownotunique'] = '&#1053;&#1077;&#1090; &#1091;&#1085;&#1080;&#1082;&#1072;&#1083;&#1100;&#1085;&#1086;&#1075;&#1086; &#1080;&#1076;&#1077;&#1085;&#1090;&#1080;&#1092;&#1080;&#1082;&#1072;&#1090;&#1086;&#1088;&#1072; &#1076;&#1083;&#1103; &#1101;&#1090;&#1086;&#1081; &#1079;&#1072;&#1087;&#1080;&#1089;&#1080;.';
 	$lang['strnoreportsdb'] = '&#1042;&#1099; &#1085;&#1077; &#1089;&#1086;&#1079;&#1076;&#1072;&#1083;&#1080; &#1073;&#1072;&#1079;&#1091; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1086;&#1090;&#1095;&#1077;&#1090;&#1086;&#1074;. &#1063;&#1080;&#1090;&#1072;&#1081;&#1090;&#1077; &#1088;&#1072;&#1079;&#1098;&#1103;&#1089;&#1085;&#1077;&#1085;&#1080;&#1103; &#1074; &#1092;&#1072;&#1081;&#1083;&#1077; INSTALL.';
	$lang['strnouploads'] = '&#1047;&#1072;&#1075;&#1088;&#1091;&#1079;&#1082;&#1072; &#1092;&#1072;&#1081;&#1083;&#1072; &#1085;&#1077;&#1074;&#1086;&#1079;&#1084;&#1086;&#1078;&#1085;&#1072;.';
	$lang['strimporterror'] = '&#1054;&#1096;&#1080;&#1073;&#1082;&#1072; &#1080;&#1084;&#1087;&#1086;&#1088;&#1090;&#1072;.';
	$lang['strimporterrorline'] = '&#1054;&#1096;&#1080;&#1073;&#1082;&#1072; &#1082;&#1072;&#1085;&#1072;&#1083;&#1072; &#1087;&#1088;&#1080; &#1080;&#1084;&#1087;&#1086;&#1088;&#1090;&#1077; %s.';

	// Tables
	$lang['strtable'] = '&#1058;&#1072;&#1073;&#1083;&#1080;&#1094;&#1072;';
	$lang['strtables'] = '&#1058;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099;';
	$lang['strshowalltables'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099;';
	$lang['strnotables'] = '&#1058;&#1072;&#1073;&#1083;&#1080;&#1094; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strnotable'] = ' &#1058;&#1072;&#1073;&#1083;&#1080;&#1094;&#1072; &#1085;&#1077; &#1086;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;&#1072;.';
	$lang['strcreatetable'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1091;';
	$lang['strtablename'] = '&#1048;&#1084;&#1103; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099;';
	$lang['strtableneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1086;&#1087;&#1088;&#1077;&#1076;&#1077;&#1083;&#1080;&#1090;&#1100; &#1080;&#1084;&#1103; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099;.';
	$lang['strtableneedsfield'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1086;&#1087;&#1088;&#1077;&#1076;&#1077;&#1083;&#1080;&#1090;&#1100; &#1087;&#1086; &#1082;&#1088;&#1072;&#1081;&#1085;&#1077;&#1081; &#1084;&#1077;&#1088;&#1077; &#1086;&#1076;&#1085;&#1086; &#1087;&#1086;&#1083;&#1077;.';
	$lang['strtableneedscols'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1076;&#1086;&#1087;&#1091;&#1089;&#1090;&#1080;&#1084;&#1086;&#1077; &#1095;&#1080;&#1089;&#1083;&#1086; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;&#1086;&#1074;.';
	$lang['strtablecreated'] = '&#1058;&#1072;&#1073;&#1083;&#1080;&#1094;&#1072; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;&#1072;.';
	$lang['strtablecreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdroptable'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1076;&#1072;&#1083;&#1080;&#1090;&#1100; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1091; &quot;%s&quot;?';
	$lang['strtabledropped'] = '&#1058;&#1072;&#1073;&#1083;&#1080;&#1094;&#1072; &#1091;&#1076;&#1072;&#1083;&#1077;&#1085;&#1072;.';
	$lang['strtabledroppedbad'] = '&#1059;&#1076;&#1072;&#1083;&#1077;&#1085;&#1080;&#1077; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfemptytable'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1086;&#1095;&#1080;&#1089;&#1090;&#1080;&#1090;&#1100; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1091; &quot;%s&quot;?';
	$lang['strtableemptied'] = '&#1058;&#1072;&#1073;&#1083;&#1080;&#1094;&#1072; &#1086;&#1095;&#1080;&#1097;&#1077;&#1085;&#1072;.';
	$lang['strtableemptiedbad'] = '&#1054;&#1095;&#1080;&#1089;&#1090;&#1082;&#1072; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1072;.';
	$lang['strinsertrow'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1080;&#1090;&#1100; &#1079;&#1072;&#1087;&#1080;&#1089;&#1100;';
	$lang['strrowinserted'] = '&#1047;&#1072;&#1087;&#1080;&#1089;&#1100; &#1076;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;&#1072;.';
	$lang['strrowinsertedbad'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1079;&#1072;&#1087;&#1080;&#1089;&#1080; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['streditrow'] = '&#1056;&#1077;&#1076;&#1072;&#1082;&#1090;&#1080;&#1088;&#1086;&#1074;&#1072;&#1090;&#1100; &#1079;&#1072;&#1087;&#1080;&#1089;&#1100;';
	$lang['strrowupdated'] = '&#1047;&#1072;&#1087;&#1080;&#1089;&#1100; &#1086;&#1073;&#1085;&#1086;&#1074;&#1083;&#1077;&#1085;&#1072;.';
	$lang['strrowupdatedbad'] = '&#1054;&#1073;&#1085;&#1086;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1079;&#1072;&#1087;&#1080;&#1089;&#1080; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strdeleterow'] = '&#1059;&#1076;&#1072;&#1083;&#1080;&#1090;&#1100; &#1079;&#1072;&#1087;&#1080;&#1089;&#1100;';
	$lang['strconfdeleterow'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1076;&#1072;&#1083;&#1080;&#1090;&#1100; &#1079;&#1072;&#1087;&#1080;&#1089;&#1100;?';
	$lang['strrowdeleted'] = '&#1047;&#1072;&#1087;&#1080;&#1089;&#1100; &#1091;&#1076;&#1072;&#1083;&#1077;&#1085;&#1072;.';
	$lang['strrowdeletedbad'] = '&#1059;&#1076;&#1072;&#1083;&#1077;&#1085;&#1080;&#1077; &#1079;&#1072;&#1087;&#1080;&#1089;&#1080; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strsaveandrepeat'] = '&#1042;&#1089;&#1090;&#1072;&#1074;&#1080;&#1090;&#1100; &#1080; &#1087;&#1086;&#1074;&#1090;&#1086;&#1088;&#1080;&#1090;&#1100;';
	$lang['strfield'] = '&#1055;&#1086;&#1083;&#1077;';
	$lang['strfields'] = '&#1055;&#1086;&#1083;&#1103;';
	$lang['strnumfields'] = '&#1050;&#1086;&#1083;-&#1074;&#1086; &#1087;&#1086;&#1083;&#1077;&#1081;';
	$lang['strfieldneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1085;&#1072;&#1079;&#1074;&#1072;&#1090;&#1100; &#1087;&#1086;&#1083;&#1077;';
	$lang['strselectallfields'] = '&#1042;&#1099;&#1073;&#1088;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1087;&#1086;&#1083;&#1103;';
	$lang['strselectneedscol'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1087;&#1086; &#1082;&#1088;&#1072;&#1081;&#1085;&#1077;&#1081; &#1084;&#1077;&#1088;&#1077; &#1086;&#1076;&#1080;&#1085; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;';
	$lang['strselectunary'] = '&#1059;&#1085;&#1072;&#1088;&#1085;&#1099;&#1081; &#1086;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088; &#1085;&#1077; &#1084;&#1086;&#1078;&#1077;&#1090; &#1080;&#1084;&#1077;&#1090;&#1100; &#1074;&#1077;&#1083;&#1080;&#1095;&#1080;&#1085;&#1091;.';
	$lang['straltercolumn'] = '&#1048;&#1079;&#1084;&#1077;&#1085;&#1080;&#1090;&#1100; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;';
	$lang['strcolumnaltered'] = '&#1040;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090; &#1080;&#1079;&#1084;&#1077;&#1085;&#1077;&#1085;.';
	$lang['strcolumnalteredbad'] = '&#1048;&#1079;&#1084;&#1077;&#1085;&#1077;&#1085;&#1080;&#1077; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropcolumn'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1076;&#1072;&#1083;&#1080;&#1090;&#1100; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090; &quot;%s&quot; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099; &quot;%s&quot;?';
	$lang['strcolumndropped'] = '&#1040;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090; &#1091;&#1076;&#1072;&#1083;&#1077;&#1085;.';
	$lang['strcolumndroppedbad'] = '&#1059;&#1076;&#1072;&#1083;&#1077;&#1085;&#1080;&#1077; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['straddcolumn'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1080;&#1090;&#1100; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;';
	$lang['strcolumnadded'] = '&#1040;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090; &#1076;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;.';
	$lang['strcolumnaddedbad'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strdataonly'] = '&#1058;&#1086;&#1083;&#1100;&#1082;&#1086; &#1076;&#1072;&#1085;&#1085;&#1099;&#1077;';
	$lang['strcascade'] = '&#1050;&#1072;&#1089;&#1082;&#1072;&#1076;&#1086;&#1084;';
	$lang['strtablealtered'] = '&#1058;&#1072;&#1073;&#1083;&#1080;&#1094;&#1072; &#1080;&#1079;&#1084;&#1077;&#1085;&#1077;&#1085;&#1072;.';
	$lang['strtablealteredbad'] = '&#1048;&#1079;&#1084;&#1077;&#1085;&#1077;&#1085;&#1080;&#1077; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strdataonly'] = '&#1058;&#1086;&#1083;&#1100;&#1082;&#1086; &#1076;&#1072;&#1085;&#1085;&#1099;&#1077;';
	$lang['strstructureonly'] = '&#1058;&#1086;&#1083;&#1100;&#1082;&#1086; &#1089;&#1090;&#1088;&#1091;&#1082;&#1090;&#1091;&#1088;&#1091;';
	$lang['strstructureanddata'] = '&#1057;&#1090;&#1088;&#1091;&#1082;&#1090;&#1091;&#1088;&#1091; &#1080; &#1076;&#1072;&#1085;&#1085;&#1099;&#1077;';
	$lang['strtabbed'] = '&#1063;&#1077;&#1088;&#1077;&#1079; &#1090;&#1072;&#1073;&#1091;&#1083;&#1103;&#1094;&#1080;&#1102;';
	$lang['strauto'] = '&#1040;&#1074;&#1090;&#1086;';

	// Users
	$lang['struser'] = '&#1055;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;';
	$lang['strusers'] = '&#1055;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1080;';
	$lang['strusername'] = '&#1048;&#1084;&#1103; &#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1103;';
	$lang['strpassword'] = '&#1055;&#1072;&#1088;&#1086;&#1083;&#1100;';
	$lang['strsuper'] = '&#1057;&#1091;&#1087;&#1077;&#1088;&#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;?';
	$lang['strcreatedb'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1073;&#1072;&#1079;&#1091; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;?';
	$lang['strexpires'] = '&#1057;&#1088;&#1086;&#1082; &#1076;&#1077;&#1081;&#1089;&#1090;&#1074;&#1080;&#1103;';
	$lang['strsessiondefaults'] = '&#1054;&#1087;&#1094;&#1080;&#1080; &#1089;&#1077;&#1072;&#1085;&#1089;&#1072; &#1087;&#1086; &#1091;&#1084;&#1086;&#1083;&#1095;&#1072;&#1085;&#1080;&#1102;';
	$lang['strnousers'] = '&#1053;&#1077;&#1090; &#1090;&#1072;&#1082;&#1080;&#1093; &#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1077;&#1081;.';
	$lang['struserupdated'] = '&#1055;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100; &#1086;&#1073;&#1085;&#1086;&#1074;&#1083;&#1077;&#1085;.';
	$lang['struserupdatedbad'] = '&#1054;&#1073;&#1085;&#1086;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1103; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strshowallusers'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077;&#1093; &#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1077;&#1081;';
	$lang['strcreateuser'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1103;';
	$lang['struserneedsname'] = '&#1042;&#1099; &#1076;&#1086;&#1083;&#1078;&#1085;&#1099; &#1074;&#1074;&#1077;&#1089;&#1090;&#1080; &#1080;&#1084;&#1103; &#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1103;.';
	$lang['strusercreated'] = '&#1055;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;.';
	$lang['strusercreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1103; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropuser'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1076;&#1072;&#1083;&#1080;&#1090;&#1100; &#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1103; &quot;%s&quot;?';
	$lang['struserdropped'] = '&#1055;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100; &#1091;&#1076;&#1072;&#1083;&#1077;&#1085;.';
	$lang['struserdroppedbad'] = '&#1059;&#1076;&#1072;&#1083;&#1077;&#1085;&#1080;&#1077; &#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1103; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['straccount'] = '&#1040;&#1082;&#1082;&#1072;&#1091;&#1085;&#1090;';
	$lang['strchangepassword'] = '&#1048;&#1079;&#1084;&#1077;&#1085;&#1080;&#1090;&#1100; &#1087;&#1072;&#1088;&#1086;&#1083;&#1100;';
	$lang['strpasswordchanged'] = '&#1055;&#1072;&#1088;&#1086;&#1083;&#1100; &#1080;&#1079;&#1084;&#1077;&#1085;&#1077;&#1085;.';
	$lang['strpasswordchangedbad'] = '&#1048;&#1079;&#1084;&#1077;&#1085;&#1077;&#1085;&#1080;&#1077; &#1087;&#1072;&#1088;&#1086;&#1083;&#1103; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strpasswordshort'] = '&#1055;&#1072;&#1088;&#1086;&#1083;&#1100; &#1089;&#1083;&#1080;&#1096;&#1082;&#1086;&#1084; &#1082;&#1086;&#1088;&#1086;&#1090;&#1082;&#1080;&#1081;.';
	$lang['strpasswordconfirm'] = '&#1055;&#1072;&#1088;&#1086;&#1083;&#1100; &#1085;&#1077; &#1089;&#1086;&#1086;&#1090;&#1074;&#1077;&#1090;&#1089;&#1090;&#1074;&#1091;&#1077;&#1090; &#1087;&#1086;&#1076;&#1090;&#1074;&#1077;&#1088;&#1078;&#1076;&#1077;&#1085;&#1080;&#1102;.';

	// Groups
	$lang['strgroup'] = '&#1043;&#1088;&#1091;&#1087;&#1087;&#1072;';
	$lang['strgroups'] = '&#1043;&#1088;&#1091;&#1087;&#1087;&#1099;';
	$lang['strnogroup'] = '&#1043;&#1088;&#1091;&#1087;&#1087;&#1072; &#1085;&#1077; &#1086;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;&#1072;.';
	$lang['strnogroups'] = '&#1053;&#1080; &#1086;&#1076;&#1085;&#1086;&#1081; &#1075;&#1088;&#1091;&#1087;&#1087;&#1099; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strcreategroup'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1075;&#1088;&#1091;&#1087;&#1087;&#1091;';
	$lang['strshowallgroups'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1075;&#1088;&#1091;&#1087;&#1087;&#1099;';
	$lang['strgroupneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1085;&#1072;&#1079;&#1074;&#1072;&#1085;&#1080;&#1077; &#1075;&#1088;&#1091;&#1087;&#1087;&#1099;.';
	$lang['strgroupcreated'] = '&#1043;&#1088;&#1091;&#1087;&#1087;&#1072; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;&#1072;.';
	$lang['strgroupcreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1075;&#1088;&#1091;&#1087;&#1087;&#1099; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropgroup'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1076;&#1072;&#1083;&#1080;&#1090;&#1100; &#1075;&#1088;&#1091;&#1087;&#1087;&#1091; &quot;%s&quot;?';
	$lang['strgroupdropped'] = '&#1043;&#1088;&#1091;&#1087;&#1087;&#1072; &#1091;&#1076;&#1072;&#1083;&#1077;&#1085;&#1072;.';
	$lang['strgroupdroppedbad'] = '&#1059;&#1076;&#1072;&#1083;&#1077;&#1085;&#1080;&#1077; &#1075;&#1088;&#1091;&#1087;&#1087;&#1099; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strmembers'] = '&#1059;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1086;&#1074;';
	$lang['straddmember'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1080;&#1090;&#1100; &#1091;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1072;';
	$lang['strmemberadded'] = '&#1059;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082; &#1076;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;.';
	$lang['strmemberaddedbad'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1091;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strdropmember'] = '&#1059;&#1076;&#1072;&#1083;&#1080;&#1090;&#1100; &#1091;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1072;';
	$lang['strconfdropmember'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1076;&#1072;&#1083;&#1080;&#1090;&#1100; &#1091;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1072; &quot;%s&quot; &#1080;&#1079; &#1075;&#1088;&#1091;&#1087;&#1087;&#1099; &quot;%s&quot;?';
	$lang['strmemberdropped'] = '&#1059;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082; &#1091;&#1076;&#1072;&#1083;&#1077;&#1085;.';
	$lang['strmemberdroppedbad'] = '&#1059;&#1076;&#1072;&#1083;&#1077;&#1085;&#1080;&#1077; &#1091;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';

	// Privilges
	$lang['strprivilege'] = '&#1055;&#1088;&#1080;&#1074;&#1080;&#1083;&#1077;&#1075;&#1080;&#1103;';
	$lang['strprivileges'] = '&#1055;&#1088;&#1080;&#1074;&#1080;&#1083;&#1077;&#1075;&#1080;&#1080;';
	$lang['strnoprivileges'] = '&#1054;&#1073;&#1098;&#1077;&#1082;&#1090; &#1085;&#1077; &#1080;&#1084;&#1077;&#1077;&#1090; &#1087;&#1088;&#1080;&#1074;&#1080;&#1083;&#1077;&#1075;&#1080;&#1081;.';
	$lang['strgrant'] = '&#1059;&#1089;&#1080;&#1083;&#1080;&#1090;&#1100;';
	$lang['strrevoke'] = '&#1054;&#1089;&#1083;&#1072;&#1073;&#1080;&#1090;&#1100;';
	$lang['strgranted'] = '&#1055;&#1088;&#1080;&#1074;&#1080;&#1083;&#1077;&#1075;&#1080;&#1080; &#1080;&#1079;&#1084;&#1077;&#1085;&#1077;&#1085;&#1099;.';
	$lang['strgrantfailed'] = '&#1048;&#1079;&#1084;&#1077;&#1085;&#1077;&#1085;&#1080;&#1077; &#1087;&#1088;&#1080;&#1074;&#1080;&#1083;&#1077;&#1075;&#1080;&#1081; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strgrantbad'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1093;&#1086;&#1090;&#1103; &#1073;&#1099; &#1086;&#1076;&#1085;&#1086;&#1075;&#1086; &#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1103; &#1080;&#1083;&#1080; &#1075;&#1088;&#1091;&#1087;&#1087;&#1091; &#1080; &#1093;&#1086;&#1090;&#1103; &#1073;&#1099; &#1086;&#1076;&#1085;&#1091; &#1087;&#1088;&#1080;&#1074;&#1080;&#1083;&#1077;&#1075;&#1080;&#1102;.';
	$lang['stralterprivs'] = '&#1048;&#1079;&#1084;&#1077;&#1085;&#1080;&#1090;&#1100; &#1087;&#1088;&#1080;&#1074;&#1080;&#1083;&#1077;&#1075;&#1080;&#1080;';
	$lang['strgrantor'] = '&#1044;&#1086;&#1085;&#1086;&#1088;';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = '&#1041;&#1072;&#1079;&#1072; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;';
	$lang['strdatabases'] = '&#1041;&#1072;&#1079;&#1099; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;';
	$lang['strshowalldatabases'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1073;&#1072;&#1079;&#1099; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;';
	$lang['strnodatabase'] = '&#1041;&#1072;&#1079;&#1072; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1085;&#1077; &#1086;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;&#1072;.';
	$lang['strnodatabases'] = '&#1053;&#1080; &#1086;&#1076;&#1085;&#1086;&#1081; &#1073;&#1072;&#1079;&#1099; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strcreatedatabase'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1073;&#1072;&#1079;&#1091; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;';
	$lang['strdatabasename'] = '&#1048;&#1084;&#1103; &#1073;&#1072;&#1079;&#1099; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;';
	$lang['strdatabaseneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1087;&#1088;&#1080;&#1089;&#1074;&#1086;&#1080;&#1090;&#1100; &#1080;&#1084;&#1103; &#1042;&#1072;&#1096;&#1077;&#1081; &#1073;&#1072;&#1079;&#1077; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;.';
	$lang['strdatabasecreated'] = '&#1041;&#1072;&#1079;&#1072; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;&#1072;.';
	$lang['strdatabasecreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1073;&#1072;&#1079;&#1099; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropdatabase'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1080;&#1090;&#1100; &#1073;&#1072;&#1079;&#1091; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &quot;%s&quot;?';
	$lang['strdatabasedropped'] = ' &#1041;&#1072;&#1079;&#1072; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1072;.';
	$lang['strdatabasedroppedbad'] = '&#1059;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; &#1073;&#1072;&#1079;&#1099; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strentersql'] = '&#1042;&#1074;&#1077;&#1076;&#1080;&#1090;&#1077; SQL-&#1079;&#1072;&#1087;&#1088;&#1086;&#1089; &#1085;&#1080;&#1078;&#1077;:';
	$lang['strsqlexecuted'] = 'SQL-&#1079;&#1072;&#1087;&#1088;&#1086;&#1089; &#1074;&#1099;&#1087;&#1086;&#1083;&#1085;&#1077;&#1085;.';
	$lang['strvacuumgood'] = '&#1054;&#1087;&#1077;&#1088;&#1072;&#1094;&#1080;&#1103; &#1087;&#1077;&#1088;&#1077;&#1089;&#1090;&#1088;&#1086;&#1081;&#1082;&#1080; &#1079;&#1072;&#1074;&#1077;&#1088;&#1096;&#1077;&#1085;&#1072;.';
	$lang['strvacuumbad'] = '&#1054;&#1087;&#1077;&#1088;&#1072;&#1094;&#1080;&#1103; &#1087;&#1077;&#1088;&#1077;&#1089;&#1090;&#1088;&#1086;&#1081;&#1082;&#1080; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1072;.';
	$lang['stranalyzegood'] = ' &#1054;&#1087;&#1077;&#1088;&#1072;&#1094;&#1080;&#1103; &#1072;&#1085;&#1072;&#1083;&#1080;&#1079;&#1072; &#1079;&#1072;&#1074;&#1077;&#1088;&#1096;&#1077;&#1085;&#1072;.';
	$lang['stranalyzebad'] = ' &#1054;&#1087;&#1077;&#1088;&#1072;&#1094;&#1080;&#1103; &#1072;&#1085;&#1072;&#1083;&#1080;&#1079;&#1072; &#1079;&#1072;&#1074;&#1077;&#1088;&#1096;&#1077;&#1085;&#1072;.';
	$lang['strreindexgood'] = '&#1055;&#1077;&#1088;&#1077;&#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1072;&#1094;&#1080;&#1103; &#1079;&#1072;&#1074;&#1077;&#1088;&#1096;&#1077;&#1085;&#1072;.';
	$lang['strreindexbad'] = '&#1055;&#1077;&#1088;&#1077;&#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1072;&#1094;&#1080;&#1103; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1072;.';
	$lang['strfull'] = '&#1055;&#1086;&#1083;&#1085;&#1086;&#1089;&#1090;&#1100;&#1102;';
	$lang['strfreeze'] = '&#1047;&#1072;&#1084;&#1086;&#1088;&#1086;&#1079;&#1080;&#1090;&#1100;';
	$lang['strforce'] = '&#1055;&#1088;&#1080;&#1085;&#1091;&#1076;&#1080;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;';

	// Views
	$lang['strview'] = '&#1055;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077;';
	$lang['strviews'] = '&#1055;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1103;';
	$lang['strshowallviews'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1087;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1103;';
	$lang['strnoview'] = '&#1055;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strnoviews'] = '&#1053;&#1080; &#1086;&#1076;&#1085;&#1086;&#1075;&#1086; &#1087;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1103; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strcreateview'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1087;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077;';
	$lang['strviewname'] = '&#1048;&#1084;&#1103; &#1087;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1103;';
	$lang['strviewneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1080;&#1084;&#1103; &#1087;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1103;.';
	$lang['strviewneedsdef'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1086;&#1087;&#1088;&#1077;&#1076;&#1077;&#1083;&#1080;&#1090;&#1100; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;&#1099; &#1087;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1103;.';
	$lang['strviewneedsfields'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1086;&#1087;&#1088;&#1077;&#1076;&#1077;&#1083;&#1080;&#1090;&#1100; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;&#1099; &#1076;&#1083;&#1103; &#1074;&#1099;&#1073;&#1086;&#1088;&#1082;&#1080; &#1074; &#1074;&#1072;&#1096;&#1077; &#1087;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077;.';
	$lang['strviewcreated'] = '&#1055;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;&#1086;.';
	$lang['strviewcreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1087;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1103; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropview'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1080;&#1090;&#1100; &#1087;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &quot;%s&quot;?';
	$lang['strviewdropped'] = '&#1055;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1086;.';
	$lang['strviewdroppedbad'] = '&#1059;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; &#1087;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1103; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strviewupdated'] = '&#1055;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1086;&#1073;&#1085;&#1086;&#1074;&#1083;&#1077;&#1085;&#1086;.';
	$lang['strviewupdatedbad'] = '&#1054;&#1073;&#1085;&#1086;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1087;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1103; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strviewlink'] = '&#1057;&#1074;&#1103;&#1079;&#1072;&#1085;&#1085;&#1099;&#1077; &#1082;&#1083;&#1102;&#1095;&#1080;';
	$lang['strviewconditions'] = '&#1044;&#1086;&#1087;&#1086;&#1083;&#1085;&#1080;&#1090;&#1077;&#1083;&#1100;&#1085;&#1099;&#1077; &#1091;&#1089;&#1083;&#1086;&#1074;&#1080;&#1103;';
	$lang['strcreateviewwiz'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1087;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1087;&#1086;&#1084;&#1086;&#1097;&#1085;&#1080;&#1082;&#1086;&#1084;';

	// Sequences
	$lang['strsequence'] = '&#1055;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1100;';
	$lang['strsequences'] = ' &#1055;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1080;';
	$lang['strshowallsequences'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1087;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1080;';
	$lang['strnosequence'] = '&#1055;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1100; &#1085;&#1077; &#1086;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;&#1072;.';
	$lang['strnosequences'] = '&#1053;&#1080; &#1086;&#1076;&#1085;&#1086;&#1081; &#1087;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1080; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strcreatesequence'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1087;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1100;';
	$lang['strlastvalue'] = '&#1055;&#1086;&#1089;&#1083;&#1077;&#1076;&#1085;&#1077;&#1077; &#1079;&#1085;&#1072;&#1095;&#1077;&#1085;&#1080;&#1077;';
	$lang['strincrementby'] = '&#1059;&#1074;&#1077;&#1083;&#1080;&#1095;&#1077;&#1085;&#1080;&#1077; &#1085;&#1072;';
	$lang['strstartvalue'] = '&#1053;&#1072;&#1095;&#1072;&#1083;&#1100;&#1085;&#1086;&#1077; &#1079;&#1085;&#1072;&#1095;&#1077;&#1085;&#1080;&#1077;';
	$lang['strmaxvalue'] = '&#1052;&#1072;&#1082;&#1089;. &#1074;&#1077;&#1083;&#1080;&#1095;&#1080;&#1085;&#1072;';
	$lang['strminvalue'] = '&#1052;&#1080;&#1085;. &#1074;&#1077;&#1083;&#1080;&#1095;&#1080;&#1085;&#1072;';
	$lang['strcachevalue'] = '&#1056;&#1072;&#1079;&#1084;&#1077;&#1088; &#1082;&#1101;&#1096;&#1072;';
	$lang['strlogcount'] = 'Log Count';
	$lang['striscycled'] = '&#1047;&#1072;&#1094;&#1080;&#1082;&#1083;&#1080;&#1090;&#1100;?';
	$lang['strsequenceneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1080;&#1084;&#1103; &#1087;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1080;.';
	$lang['strsequencecreated'] = '&#1055;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1100; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;&#1072;.';
	$lang['strsequencecreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1087;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1080; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropsequence'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1080;&#1090;&#1100; &#1087;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1100; &quot;%s&quot;?';
	$lang['strsequencedropped'] = '&#1055;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1100; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1072;.';
	$lang['strsequencedroppedbad'] = '&#1059;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; &#1087;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1080; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strsequencereset'] = '&#1055;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1100; &#1089;&#1073;&#1088;&#1086;&#1096;&#1077;&#1085;&#1072;.';
	$lang['strsequenceresetbad'] = '&#1057;&#1073;&#1088;&#1086;&#1089; &#1087;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1080; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;.'; 

	// Indexes
	$lang['strindex'] = '&#1048;&#1085;&#1076;&#1077;&#1082;&#1089;';
	$lang['strindexes'] = '&#1048;&#1085;&#1076;&#1077;&#1082;&#1089;&#1099;';
	$lang['strindexname'] = '&#1048;&#1084;&#1103; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1072;';
	$lang['strshowallindexes'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1099;';
	$lang['strnoindex'] = '&#1048;&#1085;&#1076;&#1077;&#1082;&#1089; &#1085;&#1077; &#1086;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;.';
	$lang['strnoindexes'] = '&#1053;&#1080; &#1086;&#1076;&#1085;&#1086;&#1075;&#1086; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1072; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strcreateindex'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;';
	$lang['strtabname'] = '&#1048;&#1084;&#1103; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099;';
	$lang['strcolumnname'] = '&#1048;&#1084;&#1103; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;&#1072;';
	$lang['strindexneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1080;&#1084;&#1103; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1072;';
	$lang['strindexneedscols'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1076;&#1086;&#1087;&#1091;&#1089;&#1090;&#1080;&#1084;&#1086;&#1077; &#1082;&#1086;&#1083;&#1080;&#1095;&#1077;&#1089;&#1090;&#1074;&#1086; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;&#1086;&#1074;.';
	$lang['strindexcreated'] = '&#1048;&#1085;&#1076;&#1077;&#1082;&#1089; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;.';
	$lang['strindexcreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropindex'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1080;&#1090;&#1100; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089; &quot;%s&quot;?';
	$lang['strindexdropped'] = '&#1048;&#1085;&#1076;&#1077;&#1082;&#1089; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;.';
	$lang['strindexdroppedbad'] = '&#1059;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strkeyname'] = '&#1048;&#1084;&#1103; &#1082;&#1083;&#1102;&#1095;&#1072;';
	$lang['struniquekey'] = '&#1059;&#1085;&#1080;&#1082;&#1072;&#1083;&#1100;&#1085;&#1099;&#1081; &#1082;&#1083;&#1102;&#1095;';
	$lang['strprimarykey'] = '&#1055;&#1077;&#1088;&#1074;&#1080;&#1095;&#1085;&#1099;&#1081; &#1082;&#1083;&#1102;&#1095;';
	$lang['strindextype'] = '&#1042;&#1080;&#1076; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1072;';
	$lang['strindexname'] = '&#1048;&#1084;&#1103; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1072;';
	$lang['strtablecolumnlist'] = '&#1040;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;&#1086;&#1074; &#1074; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1077;';
	$lang['strindexcolumnlist'] = '&#1040;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;&#1086;&#1074; &#1074; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1077;';
	$lang['strconfcluster'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1082;&#1083;&#1072;&#1089;&#1090;&#1077;&#1088;&#1080;&#1079;&#1086;&#1074;&#1072;&#1090;&#1100; &quot;%s&quot;?';
	$lang['strclusteredgood'] = '&#1050;&#1083;&#1072;&#1089;&#1090;&#1077;&#1088;&#1080;&#1079;&#1072;&#1094;&#1080;&#1103; &#1079;&#1072;&#1074;&#1077;&#1088;&#1096;&#1077;&#1085;&#1072;.';
	$lang['strclusteredbad'] = '&#1050;&#1083;&#1072;&#1089;&#1090;&#1077;&#1088;&#1080;&#1079;&#1072;&#1094;&#1080;&#1103; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1072;.';

	// Rules
	$lang['strrules'] = '&#1055;&#1088;&#1072;&#1074;&#1080;&#1083;&#1072;';
	$lang['strrule'] = '&#1055;&#1088;&#1072;&#1074;&#1080;&#1083;&#1086;';
	$lang['strshowallrules'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1087;&#1088;&#1072;&#1074;&#1080;&#1083;&#1072;';
	$lang['strnorule'] = '&#1055;&#1088;&#1072;&#1074;&#1080;&#1083;&#1086; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strnorules'] = '&#1053;&#1080; &#1086;&#1076;&#1085;&#1086;&#1075;&#1086; &#1087;&#1088;&#1072;&#1074;&#1080;&#1083;&#1072; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strcreaterule'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1087;&#1088;&#1072;&#1074;&#1080;&#1083;&#1086;';
	$lang['strrulename'] = '&#1048;&#1084;&#1103; &#1087;&#1088;&#1072;&#1074;&#1080;&#1083;&#1072;';
	$lang['strruleneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1080;&#1084;&#1103; &#1087;&#1088;&#1072;&#1074;&#1080;&#1083;&#1072;.';
	$lang['strrulecreated'] = '&#1055;&#1088;&#1072;&#1074;&#1080;&#1083;&#1086; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;&#1086;.';
	$lang['strrulecreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1087;&#1088;&#1072;&#1074;&#1080;&#1083;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdroprule'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1080;&#1090;&#1100; &#1087;&#1088;&#1072;&#1074;&#1080;&#1083;&#1086; &quot;%s&quot; on &quot;%s&quot;?';
	$lang['strruledropped'] = '&#1055;&#1088;&#1072;&#1074;&#1080;&#1083;&#1086; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1086;.';
	$lang['strruledroppedbad'] = '&#1059;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; &#1087;&#1088;&#1072;&#1074;&#1080;&#1083;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';

	// Constraints
	$lang['strconstraints'] = '&#1054;&#1075;&#1088;&#1072;&#1085;&#1080;&#1095;&#1077;&#1085;&#1080;&#1103;';
	$lang['strshowallconstraints'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1086;&#1075;&#1088;&#1072;&#1085;&#1080;&#1095;&#1077;&#1085;&#1080;&#1103;';
	$lang['strnoconstraints'] = '&#1053;&#1080; &#1086;&#1076;&#1085;&#1086;&#1075;&#1086; &#1086;&#1075;&#1088;&#1072;&#1085;&#1080;&#1095;&#1077;&#1085;&#1080;&#1103; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strcreateconstraint'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1086;&#1075;&#1088;&#1072;&#1085;&#1080;&#1095;&#1077;&#1085;&#1080;&#1077;';
	$lang['strconstraintcreated'] = '&#1054;&#1075;&#1088;&#1072;&#1085;&#1080;&#1095;&#1077;&#1085;&#1080;&#1077; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;&#1086;.';
	$lang['strconstraintcreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1086;&#1075;&#1088;&#1072;&#1085;&#1080;&#1095;&#1077;&#1085;&#1080;&#1103; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropconstraint'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1080;&#1090;&#1100; &#1086;&#1075;&#1088;&#1072;&#1085;&#1080;&#1095;&#1077;&#1085;&#1080;&#1077; &quot;%s&quot; on &quot;%s&quot;?';
	$lang['strconstraintdropped'] = '&#1054;&#1075;&#1088;&#1072;&#1085;&#1080;&#1095;&#1077;&#1085;&#1080;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1086;.';
	$lang['strconstraintdroppedbad'] = '&#1059;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; &#1086;&#1075;&#1088;&#1072;&#1085;&#1080;&#1095;&#1077;&#1085;&#1080;&#1103; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['straddcheck'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1080;&#1090;&#1100; &#1087;&#1088;&#1086;&#1074;&#1077;&#1088;&#1082;&#1091;';
	$lang['strcheckneedsdefinition'] = '&#1054;&#1075;&#1088;&#1072;&#1085;&#1080;&#1095;&#1077;&#1085;&#1080;&#1077; &#1087;&#1088;&#1086;&#1074;&#1077;&#1088;&#1082;&#1080; &#1085;&#1091;&#1078;&#1076;&#1072;&#1077;&#1090;&#1089;&#1103; &#1074; &#1086;&#1087;&#1088;&#1077;&#1076;&#1077;&#1083;&#1077;&#1085;&#1080;&#1080;.';
	$lang['strcheckadded'] = '&#1054;&#1075;&#1088;&#1072;&#1085;&#1080;&#1095;&#1077;&#1085;&#1080;&#1077; &#1087;&#1088;&#1086;&#1074;&#1077;&#1088;&#1082;&#1080; &#1076;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;&#1086;.';
	$lang['strcheckaddedbad'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1086;&#1075;&#1088;&#1072;&#1085;&#1080;&#1095;&#1077;&#1085;&#1080;&#1103; &#1087;&#1088;&#1086;&#1074;&#1077;&#1088;&#1082;&#1080; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['straddpk'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1080;&#1090;&#1100; &#1087;&#1077;&#1088;&#1074;&#1080;&#1095;&#1085;&#1099;&#1081; &#1082;&#1083;&#1102;&#1095;';
	$lang['strpkneedscols'] = '&#1055;&#1077;&#1088;&#1074;&#1080;&#1095;&#1085;&#1099;&#1081; &#1082;&#1083;&#1102;&#1095; &#1076;&#1086;&#1083;&#1078;&#1077;&#1085; &#1074;&#1082;&#1083;&#1102;&#1095;&#1072;&#1090;&#1100; &#1093;&#1086;&#1090;&#1103; &#1073;&#1099; &#1086;&#1076;&#1080;&#1085; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;.';
	$lang['strpkadded'] = '&#1055;&#1077;&#1088;&#1074;&#1080;&#1095;&#1085;&#1099;&#1081; &#1082;&#1083;&#1102;&#1095; &#1076;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;.';
	$lang['strpkaddedbad'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1087;&#1077;&#1088;&#1074;&#1080;&#1095;&#1085;&#1086;&#1075;&#1086; &#1082;&#1083;&#1102;&#1095;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['stradduniq'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1080;&#1090;&#1100; &#1091;&#1085;&#1080;&#1082;&#1072;&#1083;&#1100;&#1085;&#1099;&#1081; &#1082;&#1083;&#1102;&#1095;';
	$lang['struniqneedscols'] = '&#1059;&#1085;&#1080;&#1082;&#1072;&#1083;&#1100;&#1085;&#1099;&#1081; &#1082;&#1083;&#1102;&#1095; &#1076;&#1086;&#1083;&#1078;&#1077;&#1085; &#1074;&#1082;&#1083;&#1102;&#1095;&#1072;&#1090;&#1100; &#1093;&#1086;&#1090;&#1103; &#1073;&#1099; &#1086;&#1076;&#1080;&#1085; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;.';
	$lang['struniqadded'] = '&#1059;&#1085;&#1080;&#1082;&#1072;&#1083;&#1100;&#1085;&#1099;&#1081; &#1082;&#1083;&#1102;&#1095; &#1076;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;.';
	$lang['struniqaddedbad'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1091;&#1085;&#1080;&#1082;&#1072;&#1083;&#1100;&#1085;&#1086;&#1075;&#1086; &#1082;&#1083;&#1102;&#1095;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['straddfk'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1080;&#1090;&#1100; &#1074;&#1085;&#1077;&#1096;&#1085;&#1080;&#1081; &#1082;&#1083;&#1102;&#1095;';
	$lang['strfkneedscols'] = '&#1042;&#1085;&#1077;&#1096;&#1085;&#1080;&#1081; &#1082;&#1083;&#1102;&#1095; &#1076;&#1086;&#1083;&#1078;&#1077;&#1085; &#1074;&#1082;&#1083;&#1102;&#1095;&#1072;&#1090;&#1100; &#1093;&#1086;&#1090;&#1103; &#1073;&#1099; &#1086;&#1076;&#1080;&#1085; &#1072;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;.';
	$lang['strfkneedstarget'] = '&#1042;&#1085;&#1077;&#1096;&#1085;&#1077;&#1084;&#1091; &#1082;&#1083;&#1102;&#1095;&#1091; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1094;&#1077;&#1083;&#1077;&#1074;&#1091;&#1102; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1091;.';
	$lang['strfkadded'] = '&#1042;&#1085;&#1077;&#1096;&#1085;&#1080;&#1081; &#1082;&#1083;&#1102;&#1095; &#1076;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;.';
	$lang['strfkaddedbad'] = '&#1044;&#1086;&#1073;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1074;&#1085;&#1077;&#1096;&#1085;&#1077;&#1075;&#1086; &#1082;&#1083;&#1102;&#1095;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strfktarget'] = '&#1062;&#1077;&#1083;&#1077;&#1074;&#1072;&#1103; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1072;';
	$lang['strfkcolumnlist'] = '&#1040;&#1090;&#1088;&#1080;&#1073;&#1091;&#1090;&#1099; &#1074; &#1082;&#1083;&#1102;&#1095;&#1077;';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';	

	// Functions
	$lang['strfunction'] = '&#1060;&#1091;&#1085;&#1082;&#1094;&#1080;&#1103;';
	$lang['strfunctions'] = ' &#1060;&#1091;&#1085;&#1082;&#1094;&#1080;&#1080;';
	$lang['strshowallfunctions'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1080;';
	$lang['strnofunction'] = '&#1060;&#1091;&#1085;&#1082;&#1094;&#1080;&#1103; &#1085;&#1077; &#1086;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;&#1072;.';
	$lang['strnofunctions'] = '&#1053;&#1080; &#1086;&#1076;&#1085;&#1086;&#1081; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1080; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strcreatefunction'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1102;';
	$lang['strfunctionname'] = '&#1048;&#1084;&#1103; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1080;';
	$lang['strreturns'] = '&#1042;&#1086;&#1079;&#1074;&#1088;&#1072;&#1097;&#1072;&#1077;&#1084;&#1086;&#1077; &#1079;&#1085;&#1072;&#1095;&#1077;&#1085;&#1080;&#1077;';
	$lang['strarguments'] = '&#1040;&#1088;&#1075;&#1091;&#1084;&#1077;&#1085;&#1090;&#1099;';
	$lang['strproglanguage'] = '&#1071;&#1079;&#1099;&#1082; &#1087;&#1088;&#1086;&#1075;&#1088;&#1072;&#1084;&#1084;&#1080;&#1088;&#1086;&#1074;&#1072;&#1085;&#1080;&#1103;';
	$lang['strproglanguage'] = '&#1071;&#1079;&#1099;&#1082;';
	$lang['strfunctionneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1080;&#1084;&#1103; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1080;.';
	$lang['strfunctionneedsdef'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1086;&#1087;&#1088;&#1077;&#1076;&#1077;&#1083;&#1080;&#1090;&#1100; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1102;.';
	$lang['strfunctioncreated'] = '&#1060;&#1091;&#1085;&#1082;&#1094;&#1080;&#1103; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;&#1072;.';
	$lang['strfunctioncreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1080; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropfunction'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1080;&#1090;&#1100; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1102; &quot;%s&quot;?';
	$lang['strfunctiondropped'] = '&#1060;&#1091;&#1085;&#1082;&#1094;&#1080;&#1103; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1072;.';
	$lang['strfunctiondroppedbad'] = '&#1059;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1080; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strfunctionupdated'] = '&#1060;&#1091;&#1085;&#1082;&#1094;&#1080;&#1103; &#1086;&#1073;&#1085;&#1086;&#1074;&#1083;&#1077;&#1085;&#1072;.';
	$lang['strfunctionupdatedbad'] = '&#1054;&#1073;&#1085;&#1086;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1080; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';

	// Triggers
	$lang['strtrigger'] = '&#1058;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088;';
	$lang['strtriggers'] = ' &#1058;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088;&#1099;';
	$lang['strshowalltriggers'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1090;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088;&#1099;';
	$lang['strnotrigger'] = '&#1058;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088; &#1085;&#1077; &#1086;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;.';
	$lang['strnotriggers'] = '&#1053;&#1080; &#1086;&#1076;&#1085;&#1086;&#1075;&#1086; &#1090;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088;&#1072; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strcreatetrigger'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1090;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088;';
	$lang['strtriggerneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1080;&#1084;&#1103; &#1090;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088;&#1072;.';
	$lang['strtriggerneedsfunc'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1086;&#1087;&#1088;&#1077;&#1076;&#1077;&#1083;&#1080;&#1090;&#1100; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1102; &#1090;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088;&#1072;.';
	$lang['strtriggercreated'] = '&#1058;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;.';
	$lang['strtriggercreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1090;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdroptrigger'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1080;&#1090;&#1100; &#1090;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088; &quot;%s&quot; &#1085;&#1072; &quot;%s&quot;?';
	$lang['strtriggerdropped'] = '&#1058;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;.';
	$lang['strtriggerdroppedbad'] = '&#1059;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; &#1090;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strtriggeraltered'] = '&#1058;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088; &#1080;&#1079;&#1084;&#1077;&#1085;&#1077;&#1085;.';
	$lang['strtriggeralteredbad'] = '&#1048;&#1079;&#1084;&#1077;&#1085;&#1077;&#1085;&#1080;&#1077; &#1090;&#1088;&#1080;&#1075;&#1075;&#1077;&#1088;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';

	// Types
	$lang['strtype'] = '&#1058;&#1080;&#1087; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;';
	$lang['strtypes'] = '&#1058;&#1080;&#1087;&#1099; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;';
	$lang['strshowalltypes'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1090;&#1080;&#1087;&#1099; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;';
	$lang['strnotype'] = '&#1058;&#1080;&#1087; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1085;&#1077; &#1086;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;.';
	$lang['strnotypes'] = '&#1053;&#1080; &#1086;&#1076;&#1085;&#1086;&#1075;&#1086; &#1090;&#1080;&#1087;&#1072; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strcreatetype'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1090;&#1080;&#1087; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;';
	$lang['strtypename'] = '&#1048;&#1084;&#1103; &#1090;&#1080;&#1087;&#1072; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;';
	$lang['strinputfn'] = '&#1060;&#1091;&#1085;&#1082;&#1094;&#1080;&#1103; &#1074;&#1074;&#1086;&#1076;&#1072;';
	$lang['stroutputfn'] = '&#1060;&#1091;&#1085;&#1082;&#1094;&#1080;&#1103; &#1074;&#1099;&#1074;&#1086;&#1076;&#1072;';
	$lang['strpassbyval'] = '&#1055;&#1077;&#1088;&#1077;&#1076;&#1072;&#1090;&#1100; &#1087;&#1086; &#1079;&#1085;&#1072;&#1095;&#1077;&#1085;&#1080;&#1102;?';
	$lang['stralignment'] = '&#1042;&#1099;&#1088;&#1072;&#1074;&#1085;&#1080;&#1074;&#1072;&#1085;&#1080;&#1077;';
	$lang['strelement'] = '&#1069;&#1083;&#1077;&#1084;&#1077;&#1085;&#1090;';
	$lang['strdelimiter'] = '&#1056;&#1072;&#1079;&#1076;&#1077;&#1083;&#1080;&#1090;&#1077;&#1083;&#1100;';
	$lang['strstorage'] = 'Storage';
	$lang['strtypeneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1080;&#1084;&#1103; &#1090;&#1080;&#1087;&#1072; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;.';
	$lang['strtypeneedslen'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1088;&#1072;&#1079;&#1084;&#1077;&#1088; &#1076;&#1083;&#1103; &#1090;&#1080;&#1087;&#1072; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093;.';
	$lang['strtypecreated'] = '&#1058;&#1080;&#1087; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;.';
	$lang['strtypecreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1090;&#1080;&#1087;&#1072; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdroptype'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1080;&#1090;&#1100; &#1090;&#1080;&#1087; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &quot;%s&quot;?';
	$lang['strtypedropped'] = '&#1058;&#1080;&#1087; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;.';
	$lang['strtypedroppedbad'] = '&#1059;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; &#1090;&#1080;&#1087;&#1072; &#1076;&#1072;&#1085;&#1085;&#1099;&#1093; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';

	// Schemas
	$lang['strschema'] = '&#1057;&#1093;&#1077;&#1084;&#1072;';
	$lang['strschemas'] = '&#1057;&#1093;&#1077;&#1084;&#1099;';
	$lang['strshowallschemas'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1089;&#1093;&#1077;&#1084;&#1099;';
	$lang['strnoschema'] = '&#1057;&#1093;&#1077;&#1084;&#1072; &#1085;&#1077; &#1086;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;&#1072;.';
	$lang['strnoschemas'] = '&#1053;&#1080; &#1086;&#1076;&#1085;&#1086;&#1081; &#1089;&#1093;&#1077;&#1084;&#1099; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strcreateschema'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1089;&#1093;&#1077;&#1084;&#1091;';
	$lang['strschemaname'] = '&#1048;&#1084;&#1103; &#1089;&#1093;&#1077;&#1084;&#1099;';
	$lang['strschemaneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1080;&#1084;&#1103; &#1089;&#1093;&#1077;&#1084;&#1099;.';
	$lang['strschemacreated'] = '&#1057;&#1093;&#1077;&#1084;&#1072; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;&#1072;.';
	$lang['strschemacreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1089;&#1093;&#1077;&#1084;&#1099; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropschema'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1080;&#1090;&#1100; &#1089;&#1093;&#1077;&#1084;&#1091; &quot;%s&quot;?';
	$lang['strschemadropped'] = '&#1057;&#1093;&#1077;&#1084;&#1072; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1072;.';
	$lang['strschemadroppedbad'] = '&#1059;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; &#1089;&#1093;&#1077;&#1084;&#1099; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strschemaaltered'] = '&#1057;&#1093;&#1077;&#1084;&#1072; &#1086;&#1073;&#1085;&#1086;&#1074;&#1083;&#1077;&#1085;&#1072;.';
	$lang['strschemaalteredbad'] = '&#1054;&#1073;&#1085;&#1086;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1089;&#1093;&#1077;&#1084;&#1099; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';

	// Reports
	$lang['strreport'] = '&#1054;&#1090;&#1095;&#1077;&#1090;';
	$lang['strreports'] = '&#1054;&#1090;&#1095;&#1077;&#1090;&#1099;';
	$lang['strshowallreports'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1086;&#1090;&#1095;&#1077;&#1090;&#1099;';
	$lang['strnoreports'] = '&#1054;&#1090;&#1095;&#1077;&#1090;&#1086;&#1074; &#1085;&#1077;&#1090;.';
	$lang['strcreatereport'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1086;&#1090;&#1095;&#1077;&#1090;';
	$lang['strreportdropped'] = '&#1054;&#1090;&#1095;&#1077;&#1090; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;.';
	$lang['strreportdroppedbad'] = '&#1059;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; &#1086;&#1090;&#1095;&#1077;&#1090;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropreport'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1080;&#1090;&#1100; &#1086;&#1090;&#1095;&#1077;&#1090; &quot;%s&quot;?';
	$lang['strreportneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1080;&#1084;&#1103; &#1086;&#1090;&#1095;&#1077;&#1090;&#1072;.';
	$lang['strreportneedsdef'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; SQL-&#1079;&#1072;&#1087;&#1088;&#1086;&#1089; &#1076;&#1083;&#1103; &#1042;&#1072;&#1096;&#1077;&#1075;&#1086; &#1086;&#1090;&#1095;&#1077;&#1090;&#1072;.';
	$lang['strreportcreated'] = '&#1054;&#1090;&#1095;&#1077;&#1090; &#1089;&#1086;&#1093;&#1088;&#1072;&#1085;&#1077;&#1085;.';
	$lang['strreportcreatedbad'] = '&#1057;&#1086;&#1093;&#1088;&#1072;&#1085;&#1077;&#1085;&#1080;&#1077; &#1086;&#1090;&#1095;&#1077;&#1090;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';

	// Domains
	$lang['strdomain'] = '&#1044;&#1086;&#1084;&#1077;&#1085;';
	$lang['strdomains'] = '&#1044;&#1086;&#1084;&#1077;&#1085;&#1099;';
	$lang['strshowalldomains'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1076;&#1086;&#1084;&#1077;&#1085;&#1099;';
	$lang['strnodomains'] = '&#1053;&#1080; &#1086;&#1076;&#1085;&#1086;&#1075;&#1086; &#1076;&#1086;&#1084;&#1077;&#1085;&#1072; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strcreatedomain'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1076;&#1086;&#1084;&#1077;&#1085;';
	$lang['strdomaindropped'] = '&#1044;&#1086;&#1084;&#1077;&#1085; &#1091;&#1076;&#1072;&#1083;&#1077;&#1085;.';
	$lang['strdomaindroppedbad'] = '&#1059;&#1076;&#1072;&#1083;&#1077;&#1085;&#1080;&#1077; &#1076;&#1086;&#1084;&#1077;&#1085;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropdomain'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1076;&#1072;&#1083;&#1080;&#1090;&#1100; &#1076;&#1086;&#1084;&#1077;&#1085; &quot;%s&quot;?';
	$lang['strdomainneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1080;&#1084;&#1103; &#1076;&#1086;&#1084;&#1077;&#1085;&#1072;.';
	$lang['strdomaincreated'] = '&#1044;&#1086;&#1084;&#1077;&#1085; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;.';
	$lang['strdomaincreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1076;&#1086;&#1084;&#1077;&#1085;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';	
	$lang['strdomainaltered'] = '&#1044;&#1086;&#1084;&#1077;&#1085; &#1080;&#1079;&#1084;&#1077;&#1085;&#1077;&#1085;.';
	$lang['strdomainalteredbad'] = '&#1048;&#1079;&#1084;&#1077;&#1085;&#1077;&#1085;&#1080;&#1077; &#1076;&#1086;&#1084;&#1077;&#1085;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';	

	// Operators
	$lang['stroperator'] = '&#1054;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;';
	$lang['stroperators'] = '&#1054;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1099;';
	$lang['strshowalloperators'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1089;&#1077; &#1086;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1099;';
	$lang['strnooperator'] = '&#1054;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088; &#1085;&#1077; &#1086;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;.';
	$lang['strnooperators'] = '&#1054;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1099; &#1085;&#1077; &#1086;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;&#1099;.';
	$lang['strcreateoperator'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1090;&#1100; &#1086;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;';
	$lang['strleftarg'] = '&#1058;&#1080;&#1087; &#1083;&#1077;&#1074;&#1086;&#1075;&#1086; &#1072;&#1088;&#1075;&#1091;&#1084;&#1077;&#1085;&#1090;&#1072;';
	$lang['strrightarg'] = '&#1058;&#1080;&#1087; &#1087;&#1088;&#1072;&#1074;&#1086;&#1075;&#1086; &#1072;&#1088;&#1075;&#1091;&#1084;&#1077;&#1085;&#1090;&#1072;';
	$lang['strcommutator'] = '&#1055;&#1088;&#1077;&#1086;&#1073;&#1088;&#1072;&#1079;&#1086;&#1074;&#1072;&#1085;&#1080;&#1077;';
	$lang['strnegator'] = '&#1054;&#1090;&#1088;&#1080;&#1094;&#1072;&#1085;&#1080;&#1077;';
	$lang['strrestrict'] = '&#1054;&#1089;&#1083;&#1072;&#1073;&#1083;&#1077;&#1085;&#1080;&#1077;';
	$lang['strjoin'] = '&#1054;&#1073;&#1098;&#1077;&#1076;&#1080;&#1085;&#1077;&#1085;&#1080;&#1077;';
	$lang['strhashes'] = '&#1061;&#1077;&#1096;&#1080;&#1088;&#1086;&#1074;&#1072;&#1085;&#1080;&#1077;';
	$lang['strmerges'] = '&#1057;&#1083;&#1080;&#1103;&#1085;&#1080;&#1077;';
	$lang['strleftsort'] = '&#1057;&#1086;&#1090;&#1080;&#1088;&#1086;&#1074;&#1082;&#1072; &#1087;&#1086; &#1083;&#1077;&#1074;&#1086;&#1084;&#1091;';
	$lang['strrightsort'] = '&#1057;&#1086;&#1090;&#1080;&#1088;&#1086;&#1074;&#1082;&#1072; &#1087;&#1086; &#1087;&#1088;&#1072;&#1074;&#1086;&#1084;&#1091;';
	$lang['strlessthan'] = '&#1052;&#1077;&#1085;&#1100;&#1096;&#1077;';
	$lang['strgreaterthan'] = '&#1041;&#1086;&#1083;&#1100;&#1096;&#1077;';
	$lang['stroperatorneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1085;&#1072;&#1079;&#1074;&#1072;&#1085;&#1080;&#1077; &#1086;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1072;.';
	$lang['stroperatorcreated'] = '&#1054;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;';
	$lang['stroperatorcreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1086;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
	$lang['strconfdropoperator'] = '&#1042;&#1099; &#1091;&#1074;&#1077;&#1088;&#1077;&#1085;&#1099;, &#1095;&#1090;&#1086; &#1093;&#1086;&#1090;&#1080;&#1090;&#1077; &#1091;&#1085;&#1080;&#1095;&#1090;&#1086;&#1078;&#1080;&#1090;&#1100; &#1086;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088; &quot;%s&quot;?';
	$lang['stroperatordropped'] = '&#1054;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088; &#1091;&#1076;&#1072;&#1083;&#1077;&#1085;.';
	$lang['stroperatordroppedbad'] = '&#1059;&#1076;&#1072;&#1083;&#1077;&#1085;&#1080;&#1077; &#1086;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1072; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';

	// Casts
	$lang['strcasts'] = '&#1054;&#1073;&#1088;&#1072;&#1079;&#1094;&#1099;';
	$lang['strnocasts'] = '&#1054;&#1073;&#1088;&#1072;&#1079;&#1094;&#1086;&#1074; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strsourcetype'] = '&#1058;&#1080;&#1087; &#1080;&#1089;&#1090;&#1086;&#1095;&#1085;&#1080;&#1082;&#1072;';
	$lang['strtargettype'] = '&#1058;&#1080;&#1087; &#1087;&#1088;&#1080;&#1077;&#1084;&#1085;&#1080;&#1082;&#1072;';
	$lang['strimplicit'] = '&#1053;&#1077;&#1103;&#1074;&#1085;&#1099;&#1081;';
	$lang['strinassignment'] = '&#1042; &#1085;&#1072;&#1079;&#1085;&#1072;&#1095;&#1077;&#1085;&#1080;&#1080;';
	$lang['strbinarycompat'] = '(&#1076;&#1074;&#1086;&#1080;&#1095;&#1085;&#1086; &#1089;&#1086;&#1074;&#1084;&#1077;&#1089;&#1090;&#1080;&#1084;&#1099;&#1081;)';
	
	// Conversions
	$lang['strconversions'] = '&#1055;&#1088;&#1077;&#1086;&#1073;&#1088;&#1072;&#1079;&#1086;&#1074;&#1072;&#1085;&#1080;&#1077;';
	$lang['strnoconversions'] = '&#1055;&#1088;&#1077;&#1086;&#1073;&#1088;&#1072;&#1079;&#1086;&#1074;&#1072;&#1085;&#1080;&#1081; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strsourceencoding'] = '&#1050;&#1086;&#1076;&#1080;&#1088;&#1086;&#1074;&#1082;&#1072; &#1080;&#1089;&#1090;&#1086;&#1095;&#1085;&#1080;&#1082;&#1072;';
	$lang['strtargetencoding'] = '&#1050;&#1086;&#1076;&#1080;&#1088;&#1086;&#1074;&#1082;&#1072; &#1087;&#1088;&#1080;&#1077;&#1084;&#1085;&#1080;&#1082;&#1072;';
	
	// Languages
	$lang['strlanguages'] = '&#1071;&#1079;&#1099;&#1082;&#1080;';
	$lang['strnolanguages'] = '&#1071;&#1079;&#1099;&#1082;&#1086;&#1074; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['strtrusted'] = '&#1055;&#1088;&#1086;&#1074;&#1077;&#1088;&#1077;&#1085;&#1086;';
	
	// Info
	$lang['strnoinfo'] = '&#1053;&#1077;&#1090; &#1076;&#1086;&#1089;&#1090;&#1091;&#1087;&#1085;&#1086;&#1081; &#1080;&#1085;&#1092;&#1086;&#1088;&#1084;&#1072;&#1094;&#1080;&#1080;.';
	$lang['strreferringtables'] = '&#1057;&#1089;&#1099;&#1083;&#1072;&#1102;&#1097;&#1080;&#1077;&#1089;&#1103; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099;';
	$lang['strparenttables'] = '&#1056;&#1086;&#1076;&#1080;&#1090;&#1077;&#1083;&#1100;&#1089;&#1082;&#1080;&#1077; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099;';
	$lang['strchildtables'] = '&#1044;&#1086;&#1095;&#1077;&#1088;&#1085;&#1080;&#1077; &#1090;&#1072;&#1073;&#1083;&#1080;&#1094;&#1099;';

	// Aggregates
	$lang['straggregates'] = '&#1040;&#1075;&#1088;&#1077;&#1075;&#1072;&#1090;&#1085;&#1099;&#1077; &#1074;&#1099;&#1088;&#1072;&#1078;&#1077;&#1085;&#1080;&#1103;';
	$lang['strnoaggregates'] = '&#1040;&#1075;&#1088;&#1077;&#1075;&#1072;&#1090;&#1085;&#1099;&#1093; &#1074;&#1099;&#1088;&#1072;&#1078;&#1077;&#1085;&#1080;&#1081; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['stralltypes'] = '(&#1042;&#1089;&#1077; &#1090;&#1080;&#1087;&#1099;)';

	// Operator Classes
	$lang['stropclasses'] = '&#1050;&#1083;&#1072;&#1089;&#1089;&#1099; &#1086;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1086;&#1074;';
	$lang['strnoopclasses'] = '&#1050;&#1083;&#1072;&#1089;&#1089;&#1086;&#1074; &#1086;&#1087;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1086;&#1074; &#1085;&#1077; &#1085;&#1072;&#1081;&#1076;&#1077;&#1085;&#1086;.';
	$lang['straccessmethod'] = '&#1052;&#1077;&#1090;&#1086;&#1076; &#1076;&#1086;&#1089;&#1090;&#1091;&#1087;&#1072;';

	// Stats and performance
	$lang['strrowperf'] = '&#1055;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1079;&#1072;&#1087;&#1080;&#1089;&#1080;';
	$lang['strioperf'] = '&#1055;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1074;&#1074;&#1086;&#1076;&#1072;/&#1074;&#1099;&#1074;&#1086;&#1076;&#1072;';
	$lang['stridxrowperf'] = '&#1055;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1072; &#1079;&#1072;&#1087;&#1080;&#1089;&#1080;';
	$lang['stridxioperf'] = '&#1055;&#1088;&#1077;&#1076;&#1089;&#1090;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;&#1072; &#1074;&#1074;&#1086;&#1076;&#1072;/&#1074;&#1099;&#1074;&#1086;&#1076;&#1072;';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = '&#1055;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1099;&#1081;';
	$lang['strscan'] = '&#1057;&#1082;&#1072;&#1085;&#1080;&#1088;&#1086;&#1074;&#1072;&#1090;&#1100;';
	$lang['strread'] = '&#1063;&#1080;&#1090;&#1072;&#1090;&#1100;';
	$lang['strfetch'] = '&#1048;&#1079;&#1074;&#1083;&#1077;&#1095;&#1100;';
	$lang['strheap'] = '&#1052;&#1091;&#1089;&#1086;&#1088;';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'TOAST &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;';
	$lang['strcache'] = '&#1050;&#1077;&#1096;';
	$lang['strdisk'] = '&#1044;&#1080;&#1089;&#1082;';
	$lang['strrows2'] = '&#1047;&#1072;&#1087;&#1080;&#1089;&#1080;';

	// Miscellaneous
	$lang['strtopbar'] = '%s &#1074;&#1099;&#1087;&#1086;&#1083;&#1085;&#1103;&#1077;&#1090;&#1089;&#1103; &#1085;&#1072; %s:%s -- &#1042;&#1099; &#1079;&#1072;&#1088;&#1077;&#1075;&#1080;&#1089;&#1090;&#1088;&#1080;&#1088;&#1086;&#1074;&#1072;&#1085;&#1099; &#1082;&#1072;&#1082; &quot;%s&quot;';
	$lang['strtimefmt'] = ' j-m-Y  g:i';
	$lang['strhelp'] = '&#1055;&#1086;&#1084;&#1086;&#1097;&#1100;';

?>
